@@ -44,7 +44,7 @@ from requests import get as _rget
 from tqdm.auto import tqdm as _tqdma
 import contextlib as _contextlib
 from mdciao.cli import residue_neighborhoods as _residue_neighborhoods, interface as _interface
-from mdciao.nomenclature import LabelerGPCR as _LabelerGPCR, LabelerCGN as _LabelerCGN
+from mdciao.nomenclature import LabelerGPCR as _LabelerGPCR, LabelerCGN as _LabelerCGN, LabelerKLIFS as _LabelerKLIFS
 from tempfile import TemporaryDirectory as _TDir, TemporaryFile as _TF
 import io as _io
 @_contextlib.contextmanager
@@ -80,9 +80,11 @@ class ExamplesCLTs(object):
         self.xtc = filenames.traj_xtc
         self.pdb = filenames.top_pdb
         self.GPCRlabs_file = filenames.adrb2_human_xlsx
+        self.KLIFSlabs_file = filenames.KLIFS_P31751_xlsx
         self.CGN_file = filenames.CGN_3SN6
         self.sitefile = filenames.tip_json
         self.pdb_3SN6 = filenames.pdb_3SN6
+        self.KLIFS_pdb = filenames.pdb_3E8D
 
         self.test = test
         cwd = _getcwd()
@@ -132,6 +134,12 @@ class ExamplesCLTs(object):
                 "%s" % self.GPCRlabs_file,
                 "-t %s" % self.pdb]
 
+    @property
+    def mdc_KLIFS_overview(self):
+        return ["mdc_KLIFS_overview.py",
+                "%s" % self.KLIFSlabs_file,
+                "-t %s" % self.KLIFS_pdb]
+
     @property
     def mdc_CGN_overview(self):
         # This is the only one that needs network access
@@ -194,7 +202,8 @@ class ExamplesCLTs(object):
 
     def _join_args(self,clt):
         oneline = self.__getattribute__(clt)
-        if self.test and all([istr not in clt for istr in ["_overview", "mdc_fragments", "mdc_pdb"]]):
+        # Only add the -ni argument where it's needed
+        if self.test and all([istr not in clt for istr in ["_overview", "mdc_fragments", "mdc_pdb", "mdc_compare", "mdc_notebooks"]]):
             oneline += ["-ni"]
         return " ".join(oneline)
 
@@ -208,14 +217,13 @@ class ExamplesCLTs(object):
               "or you can paste the line below into your terminal, add/edit options and then execute:\n"%clt)
         print(oneline)
 
-    def run(self, clt,show=True, output_dir="."):
+    def run(self, clt,show=True):
         if show:
             self.show(clt)
         oneline = self._join_args(clt)
-        #if self.test:
-        #    oneline = oneline
-
-        CP = _run(oneline.split())
+        CP = []
+        for line in oneline.split("\n\n"):
+            CP.append(_run(line.split()))
         if self.test:
             return CP
 
@@ -241,6 +249,7 @@ def ContactGroupL394(**kwargs):
     CG : a :obj:`~mdciao.contacts.ContactGroup`
 
     """
+    # TODO make a method out of this link+cd_tmpdir+return
     with _TDir(suffix="_mdciao_example_CG") as t:
         for fn in [filenames.pdb_3SN6, filenames.traj_xtc,
                    filenames.top_pdb,
@@ -297,9 +306,9 @@ def notebooks(folder ="mdciao_notebooks"):
 
     dest = _recursive_prompt(_path.join(pwd, folder), folder, verbose=True)
     print("Copying file(s):"
-          "\n %s"%"\n -".join(nbs))
+          "\n -%s"%"\n -".join(nbs))
     _mkdir(dest)
-    print("Here::")
+    print("Here:")
     for ff in nbs:
         _shcopy(ff,dest)
         print(" %s"%_path.join(dest,_path.basename(ff)))
@@ -368,25 +377,59 @@ def _recursive_prompt(input_path, pattern, count=1, verbose=False, is_file=False
         return _path.join(cwd,answer)
 
 
-def fetch_example_data(url="http://proteinformatics.org/mdciao/mdciao_example.zip",
+def fetch_example_data(alias_or_url="b2ar@Gs",
                        unzip=True):
-    r"""
-    Download the example data from the url and unzip it to the working directory.
+    r""" Download the example data as zipfile and unzip it to the working directory.
 
-    This example data is kindly provided by Dr. H. Batebi.
+    This data is used in the notebooks:
+     * Manuscript.ipynb (b2ar@Gs)
+     * Tutorial.ipynb (b2ar@Gs)
+     * Missing_Contacts.ipynb (b2ar@Gs)
+     * EGFR Kinase Inhibitors.ipynb (EGFR)
+     * Comparing_CGs_Bars.ipyn (cov19)
+     * Comparing_CGs_Flares.ipynb (cov19)
+    which can all be run locally issuing,
+    from the CLI:
 
+    >>>  mdc_notebooks.py
+
+    or from the API:
+
+    >>> mdciao.examples.notebooks()
+
+    Note
+    ----
     New filenames for the downloaded file, and the resulting folder
-    will be generated to avoid overwriting.
-
-    No files will be overwritten when extracting.
+    will be generated to avoid overwriting. No files will
+    be overwritten when extracting.
 
     Parameters
     ----------
-    url : str
-        The url to download from
+    alias_or_url : str
+        The url or the alias to download example data.
+        Currently, these are the available aliases and their urls
+         * b2ar@Gs : https://proteinformatics.uni-leipzig.de/mdciao/mdciao_example.zip
+          Beta 2 adrenergic receptor in complex with Gs-protein. Provided
+          kindly by H. Batebi (1 traj, ca. 10 MB, 280 frames, dt = 10 ps)
+
+         * EGFR : http://proteinformatics.uni-leipzig.de/mdciao/example_kinases.zip
+          Epidermal Growth Factor Receptor (EGFR) in complex with
+          four inhibitors. The inhibitors and their PDB IDs are
+          P31@3POZ, W321@3W32, EUX1@6LUB and  7VH1@7VRE.
+          The data has been generated using `TeachOpenCADD <https://projects.volkamerlab.org/teachopencadd/index.html>`_ .
+          (4 trajs, ca 10 MB each, ca 500 frames each, dt = 1ns)
+
+         * cov19 : https://proteinformatics.uni-leipzig.de/mdciao/example_cov19.zip
+          SARS-CoV-2 spike protein receptor binding domain (RBD) bound
+          to human angiotensin converting enzyme-related carboypeptidase (ACE2).
+          The files already contain processed trajectory data, in the form
+          of mdciao.contacts.ContactGroup-objects stored as npy files.
+          Original data generated at the Chodera Lab by Ivy Zhang,
+          made available via `molSSI <https://covid.molssi.org//simulations/#foldinghome-simulations-of-the-sars-cov-2-spike-rbd-bound-to-human-ace2>`_.
+          (1 npy file with interfaces for 4 setups and one sample trajectory file, ca 35 MB)
+
     unzip : bool, default is True
-        Try unzipping the file
-        after downloading
+        Try unzipping the file after downloading
 
     Returns
     -------
@@ -394,6 +437,18 @@ def fetch_example_data(url="http://proteinformatics.org/mdciao/mdciao_example.zi
         The full path to the downloaded data
 
     """
+    # TODO change to proteinformatics.org when ssl problems get fixed
+    alias2url = {"b2ar@Gs": "https://proteinformatics.uni-leipzig.de//mdciao/mdciao_example.zip",
+                 "EGFR": "https://proteinformatics.uni-leipzig.de/mdciao/example_kinases.zip",
+                 "cov19" : "https://proteinformatics.uni-leipzig.de/mdciao/example_cov19.zip",
+                 "test": "https://proteinformatics.uni-leipzig.de/mdciao/mdciao_test_small.zip"}
+
+    if alias_or_url in alias2url.keys():
+        url = alias2url[alias_or_url]
+    elif alias_or_url in alias2url.values():
+        url = alias_or_url
+    else:
+        raise ValueError("Cannot find %s in the known aliases or in the known urls:\n%s" % (alias_or_url, alias2url))
     downed_file_full = _down_url_safely(url)
     if unzip:
         return _unzip2dir(downed_file_full)
@@ -490,8 +545,13 @@ def GPCRLabeler_ardb2_human(**kwargs):
 
 def CGNLabeler_3SN6(**kwargs):
     r"""Build an :obj:`~mdciao.nomenclature.LabelerCGN` with the CGN_3SN6.txt and 3SN6.pdb files shipped with mdciao"""
-    return _LabelerCGN(filenames.CGN_3SN6,**kwargs)
-
+    with _TDir(suffix="_mdciao_example_CGNLabeler") as t:
+        for fn in [filenames.pdb_3SN6, filenames.CGN_3SN6]:
+            _link(fn, _path.join(t, _path.basename(fn)))
+        with remember_cwd():
+            _chdir(t)
+            CGN = _LabelerCGN("3SN6",**kwargs)
+    return CGN
 
 def Interface_B2AR_Gas(**kwargs):
     r"""
@@ -532,4 +592,14 @@ def Interface_B2AR_Gas(**kwargs):
     except Exception as e:
         print(b.getvalue())
         b.close()
-        raise e
\ No newline at end of file
+        raise e
+
+def KLIFSLabeler_P31751():
+    r"""Build an :obj:`~mdciao.nomenclature.LabelerKLIFS` with the KLIFS_P31751.xlsx and 3E8D.pdb.gz.pdb files shipped with mdciao"""
+    with _TDir(suffix="_mdciao_example_KLIFS") as t:
+        for fn in [filenames.KLIFS_P31751_xlsx, filenames.pdb_3E8D]:
+            _link(fn, _path.join(t, _path.basename(fn)))
+
+        with remember_cwd():
+            _chdir(t)
+            return _LabelerKLIFS("P31751", try_web_lookup=False)
\ No newline at end of file
