@@ -363,7 +363,9 @@ def col_list_from_input_and_fragments(colors,
                                                                 len(_np.hstack(residxs_as_fragments))))
     elif isinstance(colors, dict):
         assert len(colors) == len(residxs_as_fragments), (len(colors), len(residxs_as_fragments))
-        col_list = _np.hstack([[val] * len(iseg) for val, iseg in zip(colors.values(), residxs_as_fragments)])
+        col_list = [[val] * len(iseg) for val, iseg in zip(colors.values(), residxs_as_fragments)]
+        col_list = _np.array([item for sublist in col_list for item in sublist])
+        #col_list = _np.hstack([[val] * len(iseg) for val, iseg in zip(colors.values(), residxs_as_fragments)])
     else:
         raise Exception
 
@@ -574,11 +576,6 @@ def add_parent_labels(kwargs_freqs2flare, flareplot_attrs, kwargs_pffp):
 
     Parameters
     ----------
-    kwargs_pffp : dict
-        The optional arguments passed
-        initially to plot_freqs_as_flareplot.
-        It has to contain the keys "fragments"
-        and "fragment_names"
     kwargs_freqs2flare : dict
         The dictionary of kwargs computed inside
         plot_freqs_as_flareplot  by using
@@ -587,7 +584,11 @@ def add_parent_labels(kwargs_freqs2flare, flareplot_attrs, kwargs_pffp):
     flareplot_attrs : dict
         The dictionary of flareplot attributes
         produced by freqs2flare.
-
+    kwargs_pffp : dict
+        The optional arguments passed
+        initially to plot_freqs_as_flareplot.
+        It has to contain the keys "fragments"
+        and "fragment_names"
     Returns
     -------
     flareplot_attrs : dict
@@ -619,6 +620,8 @@ def add_parent_labels(kwargs_freqs2flare, flareplot_attrs, kwargs_pffp):
             plotted_fragTexts_by_input_idx = {key: val[0] for key, val in plotted_fragTexts_by_input_idx.items()}
             parent_labels, parent_xy = [], []
 
+            #Store the axis before it gets removed
+            iax = flareplot_attrs["fragment_labels"][0].axes
             _, kid_by_parents = _find_parent_list(kwargs_freqs2flare["fragments"], kwargs_pffp["fragments"])
             for parent_idx, kids in kid_by_parents.items():
                 present_kids_by_TextObject_idx = [plotted_fragTexts_by_input_idx[kk] for kk in kids if kk in plotted_fragTexts_by_input_idx.keys()]
@@ -636,7 +639,7 @@ def add_parent_labels(kwargs_freqs2flare, flareplot_attrs, kwargs_pffp):
                 parent_labels = add_fragment_labels([[None]]*len(parent_labels),
                                                     [_replace4latex(str(ifrag)) for ifrag in
                                                      parent_labels],
-                                                    flareplot_attrs["fragment_labels"][0].axes,
+                                                    iax,
                                                     fontsize=flareplot_attrs["fragment_labels"][0].get_fontsize() * 2,
                                                     r=flareplot_attrs["r"]+flareplot_attrs["dots"][0].radius*4,
                                                     xy=_np.array(parent_xy))
@@ -967,9 +970,9 @@ def _parse_residue_and_fragments(res_idxs_pairs, sparse_residues=False,
     else:
         # Checks
         _no_intersect(fragments, word="fragments")
-        assert set(res_idxs).issubset(_np.hstack(fragments)), \
-            "The input fragments do not contain all residues residx_array, " \
-            "their set difference is %s" % sorted(set(res_idxs).difference(_np.hstack(fragments)))
+        if not set(res_idxs).issubset(_np.hstack(fragments)) and isinstance(sparse_residues, bool):
+            raise ValueError("The input fragments do not contain all residues residx_array, " \
+            "their set difference is %s" % sorted(set(res_idxs).difference(_np.hstack(fragments))))
 
         if isinstance(sparse_residues, bool):
             if sparse_residues:
@@ -1024,7 +1027,7 @@ def fontsize_get(iax):
         :obj:`iax`, most likely belonging to the
         fragment-label texts
     """
-    n_polygons = len([obj for obj in iax.artists if isinstance(obj, _CP)])
+    n_polygons = len([obj for obj in iax.findobj(_CP)])
     sizes = {"n_polygons": [],
              "other": []}
 
@@ -1225,13 +1228,17 @@ def sparsify_sym_matrix(mat, eps=1e-2):
     r"""
     Return a sparse matrix
 
+    Checks of > eps are done element-wise,
+    for entire row/column sum checks,
+    see :obj: sparsify_sym_matrix_by_row_sum
+
     Parameters
     ----------
     mat : 2D np.ndarray of shape(N,N)
-        The matrix
+        The symmetric matrix
     eps : float, default is 1e-2
         Elements of :obj:`mat` are
-        considered zero if <= eps
+        considered non-zero if > eps
 
     Returns
     -------
@@ -1240,4 +1247,27 @@ def sparsify_sym_matrix(mat, eps=1e-2):
     assert (mat==mat.T).all() #checks for squareness and symmetry
     non_zeros = _np.flatnonzero(_np.any(mat > eps, axis=1))
     mat = mat[non_zeros, :][:, non_zeros]
-    return mat, non_zeros
\ No newline at end of file
+    return mat, non_zeros
+
+def sparsify_sym_matrix_by_row_sum(mat, eps=1e-2):
+    r"""
+    Return a sparse matrix
+
+    Parameters
+    ----------
+    mat : 2D np.ndarray of shape(N,N)
+        The symmetric matrix
+    eps : float, default is 1e-2
+        Rows/Columns Elements of :obj:`mat` are
+        considered non-zero row.sum() > eps
+
+    Returns
+    -------
+    mat, non_zeros
+    """
+    assert (mat==mat.T).all() #checks for squareness and symmetry
+    non_zeros = _np.flatnonzero(mat.sum(1)>eps)
+    zeros = _np.flatnonzero(mat.sum(1)<=eps)
+    discarded = mat.sum(1)[zeros].sum()
+    mat = mat[non_zeros, :][:, non_zeros]
+    return mat, non_zeros, discarded
\ No newline at end of file
