@@ -24,8 +24,7 @@ import numpy as _np
 import mdtraj as _md
 from mdtraj.core.residue_names import _PROTEIN_RESIDUES
 import mdciao.utils as _mdcu
-from  pandas import unique as _pandas_unique
-from msmtools.estimation import connected_sets as _connected_sets
+from pandas import unique as _pandas_unique
 
 _allowed_fragment_methods = ['chains',
                              'resSeq',
@@ -37,7 +36,7 @@ _allowed_fragment_methods = ['chains',
                              ]
 
 
-def print_fragments(fragments, top, **print_frag_kwargs):
+def print_fragments(fragments, top, max_lines=40, **print_frag_kwargs):
     """Inform about fragments, very thinly wrapping around :obj:`print_frag`
 
     Parameters
@@ -45,10 +44,16 @@ def print_fragments(fragments, top, **print_frag_kwargs):
     fragments : dict or list
         Iterable with the sets of residue indexes
     top : :obj:`~mdtraj.Topology`
+    max_lines : int, default is 40
+        Maximum number of lines to print. E.g. if 40,
+        first 20 and last 20 will be printed
     print_frag_kwargs : opt, keyword args for :obj:`print_frag`
 
     Returns
     -------
+    frag_list : list
+        List of the strings that
+        are being printed, for further use
 
     """
     if isinstance(fragments,list):
@@ -58,10 +63,11 @@ def print_fragments(fragments, top, **print_frag_kwargs):
     frag_list = []
     for ii, iseg in _fragments.items():
         frag_list.append(print_frag(ii, top, iseg, return_string=True, **print_frag_kwargs))
-    n = 20
+    n = _np.round(max_lines/2).astype(int)
     if n * 2 < len(frag_list):
         frag_list = frag_list[:n] + ["...[long list: omitted %u items]..." % (len(frag_list) - 2 * n)] + frag_list[-n:]
     print("\n".join(frag_list))
+    return frag_list
 
 def print_frag(frag_idx, top, fragment, fragment_desc='fragment',
                idx2label=None,
@@ -249,11 +255,11 @@ def get_fragments(top,
     elif method=='resSeq_bonds':
         residue_bond_matrix = _mdcu.bonds.top2residue_bond_matrix(top, verbose=False,
                                                       force_resSeq_breaks=True)
-        fragments = _connected_sets(residue_bond_matrix)
+        fragments = _mdcu.bonds.connected_sets(residue_bond_matrix)
     elif method=='bonds':
         residue_bond_matrix = _mdcu.bonds.top2residue_bond_matrix(top, verbose=False,
                                                       force_resSeq_breaks=False)
-        fragments = _connected_sets(residue_bond_matrix)
+        fragments = _mdcu.bonds.connected_sets(residue_bond_matrix)
         fragments = [fragments[ii] for ii in _np.argsort([fr[0] for fr in fragments])]
     elif method == "chains":
         fragments = [[rr.index for rr in ichain.residues] for ichain in top.chains]
@@ -384,6 +390,52 @@ def _break_fragments(breakers, fragments):
                 fragments = fragments[:ifrag] + subfrags + fragments[ifrag + 1:]
     return fragments
 
+#TODO use this throught the code instead of the python explicit way
+def fragment_slice(traj : _md.Trajectory, fragments, keys_or_idxs=None):
+    r"""
+
+    Slice a geometry using arbitrary fragment definitions, a la :obj:`mdtraj.Trajectory.atom_slice`
+
+    Note
+    ----
+    Regardless of the order in which the selection
+    is done (e.g. keys_or_idxs=[1,0]) the returned
+    :obj:`sliced_traj` will always be in ascending
+    order atoms as they appear in :obj:`traj`
+    Parameters
+    ----------
+    traj : :obj:`mdtraj.Trajectory`
+        The trajectory to slice
+    fragments : list or dict
+        The fragment definitions as residue indices.
+        Can be as a list or a as a dict, e.g. the output of
+        :obj:`mdciao.fragments.get_fragments` (list) or
+        :obj:`mdciao.nomenclature.LabelerGPCR.top2frags` (dict)
+    keys_or_idxs : iterable or None
+        The keys or indices of the
+        fragments to slice to, i.e.
+        to keep. If None, all
+        all fragments are used
+        as a selection
+
+    Returns
+    -------
+    sliced_traj : :obj:`mdtraj.Trajectory`
+        A copy of :obj:`traj` only with the
+        atoms present in the selected fragments
+
+    """
+
+    if keys_or_idxs is None:
+        if isinstance(fragments,dict):
+            keys_or_idxs = list(fragments.keys())
+        else:
+            keys_or_idxs = _np.arange(len(fragments))
+
+    _fragments = _np.hstack([fragments[idx] for idx in keys_or_idxs])
+
+    return traj.atom_slice([aa.index for aa in traj.top.atoms if aa.residue.index in _fragments])
+
 def _dry_fragments(fragments, top):
     r"""
     Remove water molecules from :obj:`fragments` and append them at the end as their own fragment(s)
@@ -692,7 +744,7 @@ def check_if_subfragment(sub_frag, fragname, fragments, top,
     Let's assume the GPCR-nomenclature tells us that TM6 is [0,1,2,3]
     and we have already divided the topology into fragments
     using :obj:`get_fragments`, with method "resSeq+", meaning
-    we have fragments for the receptor, Ga,Gb,Gg
+    we have fragments for the receptor,Ga,Gb,Gg
 
     The purpose is to check whether the GPCR-fragmentation is
     contained in the previous fragmentation:
@@ -709,36 +761,43 @@ def check_if_subfragment(sub_frag, fragname, fragments, top,
     Parameters
     ----------
     sub_frag : iterable of integers
+        The fragment to be checked if
+        subfragment of `fragments`
     fragname : str
     fragments : iterable of iterables of integers
-    top : :obj:`mdtraj.Trajectory`object
+    top : :obj:`~mdtraj.Trajectory` object
     map_conlab : list or dict, default is None
         maps residue idxs to consensus labels
     prompt : bool, default is True
-        When False, no prompt is issues,
+        When False, no prompt is issued,
         and the returned value is a boolean
-        whether sub_frag is actually a sub-fragment
-        of fragments or not
+        whether or not `sub_frag` is actually a sub-fragment (=subset)
+        of any one fragment of `fragments`
     Returns
     -------
-    tokeep = 1D numpy array
-        If no clashes were found, this will be contain the same residues as
+    answer : 1D numpy array or boolean
+        If `prompt` is True and no clashes were found,
+        this will contain the same residues as
         :obj:`sub_frag` without prompting the user.
-        Otherwise, the user has to input whether to leave the definition intact
-        or pick a sub-set
+        Otherwise, the user has to input whether
+        to leave the definition intact or pick a sub-set
+        If `prompt` is False, this is a boolean
+        saying whether `sub_frag` is a sub-fragment (subset)
+        of any one fragment of `fragments`
     """
     # Get the fragment idxs of all residues in this fragment
     ifrags = [_mdcu.lists.in_what_fragment(idx, fragments) for idx in sub_frag]
 
     frag_cands = [ifrag for ifrag in _pandas_unique(ifrags) if ifrag is not None]
     if not prompt:
-        return not len(frag_cands) > 1
+        return len(frag_cands) <= 1
 
     if len(frag_cands) > 1 and not keep_all:
         # This only happens if more than one fragment is present
         print_frag(fragname, top, sub_frag, fragment_desc='',
                    idx2label=map_conlab)
-        print("  %s clashes with other fragment definitions"%fragname)
+        print(" Subfragment %s clashes with other fragment definitions,\n"
+              " because the residues of %s span over more than 1 fragment:"%(fragname, fragname))
         for jj in frag_cands:
             istr = print_frag(jj, top, fragments[jj],
                               fragment_desc="   input fragment",
@@ -762,7 +821,7 @@ def _fragments_strings_to_fragments(fragment_input, top, verbose=False):
     r"""
 
     #TODO rename the strings to something else
-    Try to understand how the the user wants to fragment the topology
+    Try to understand how the user wants to fragment the topology
     Pretty flexible
 
     Check also :obj:`rangeexpand` to understand the expressions
@@ -773,7 +832,7 @@ def _fragments_strings_to_fragments(fragment_input, top, verbose=False):
     fragment_input : list of strings
         Many cases are possible
         * ["consensus"] : user wants to use
-        consenus labels such as "TM6" etc.
+        consensus labels such as "TM6" etc.
         Using "resSeq+" heuristic to fragment, and
         returns :obj:`user_wants_consensus` as True,
         this will trigger further prompts
@@ -1058,17 +1117,17 @@ def mix_fragments(highest_res_idx, consensus_frags, fragments, fragment_names):
     r"""Mix consensus frags with user-provided fragment definitions
 
     Wrapper around :obj:`mdciao.fragments.splice_orphan_fragments`,
-    will possible be merged with it in the future.
-    The wrapper does several pre and post processing things
+    will possibly be merged with it in the future.
+    The wrapper does several pre and post processing things.
     pre-processing:
-     * that makes the :obj: `consensus_frags` the main frags
-     and the :obj:`fragments` the :obj:`other_fragments`.
-     * It allows for :obj:`fragments` and/or :obj:`fragment_names`
+     * makes the `consensus_frags` the main frags
+     and the `fragments` the `other_fragments`.
+     * It allows for `fragments` and/or `fragment_names`
      to be None and creates names on the fly if needed
     post-processing:
      * renames orphan fragments as sub-fragments of original
       fragments if possible
-    In theory, if "fragments" covers all residues, no
+    In theory, if `fragments` covers all residues, no
     orphan's should be left
 
     Note
