@@ -23,6 +23,7 @@
 import argparse
 from mdciao.plots.plots import _colorstring
 from mdciao.examples.examples import ExamplesCLTs as _xCLT
+from matplotlib.colors import is_color_like as _is_color_like
 
 # https://stackoverflow.com/questions/3853722/python-argparse-how-to-insert-newline-in-the-help-text
 class SmartFormatter(argparse.HelpFormatter):
@@ -58,6 +59,18 @@ def _inform_of_parser(parser,args=None):
             fmt = '%s="%s",'
         print(fmt % (key, dval))
 
+class Populate_input_Action(argparse.Action):
+    r"""
+    Create an alias named "input_" for this argument.
+
+    Helps create a common interface for cli._fragment_overview
+
+    https://docs.python.org/3/library/argparse.html#action
+    Ctr+F "FooAction"
+    """
+    def __call__(self, parser, namespace, values, option_string=None):
+        setattr(namespace, 'input_', values)
+
 def _parser_top_traj(description=None):
     r"""
     Instantiate the basic parsers which can take topology and trajectories
@@ -152,11 +165,15 @@ def _parser_add_curve_color(parser):
                         help="Type of color used for the curves. Default is auto. Alternatives are 'P' or 'H'",
                         default="auto")
 
-def _parser_add_gray_backgroud(parser):
-    parser.add_argument('--gray-background', dest='gray_background', action='store_true',
-                        help="Use gray background when using smoothing windows."
-                             " Default is False")
-    parser.set_defaults(gray_background=False)
+def _parser_add_background(parser):
+    parser.add_argument('--background', "-bg",
+                        type=_bool_or_color_like,
+                        default=True,
+                        help="Type of background when using smoothing windows."
+                             " Default (True) is to use the unsmoothed curve's color. "
+                             " A color string e.g. 'g' or 'red' or 'gray' also works, "
+                             "as does an RGB string '0.5, 1., 0.5'.  "
+                             "Use False for no color.")
 
 def _parser_add_fragments(parser):
     parser.add_argument("-fr",'--fragments', default=['lig_resSeq+'], nargs='+',
@@ -208,8 +225,8 @@ def _parser_add_matrix(parser):
 
 def _parser_add_flare(parser):
     parser.add_argument('--no-flare', dest='flareplot', action='store_false',
-                        help="Do not produce a flare plot of interface the contact matrix. The format will be .pdf no matter "
-                             "the value of --graphic_ext")
+                        help="Do not produce a flare plot of the interface contact matrix. If produced, regardless of the '--graphic_ext', "
+                             "the flareplot will always be in .pdf-format, unless '--graphic_ext' is 'svg'.")
     parser.set_defaults(flareplot=True)
 
 def _parser_add_output_dir(parser):
@@ -291,6 +308,19 @@ def _int_or_float_type(val):
 
     return val
 
+def _bool_or_color_like(val):
+    r""" Turn strings into booleans, rgb floats keep color-like strings"""
+    if str(val).lower()=="true":
+        val = True
+    elif str(val).lower()=="false":
+        val = False
+    elif len(str(val).strip(",").split(","))==3:
+        val = [float(ii) for ii in str(val).strip(",").split(",")]
+    if not isinstance(val,bool):
+        assert _is_color_like(val), "The argument 'background' has to be boolean (True/False) or color-like, but '%s' (%s) is neither" % (
+        val, type(val))
+    return val
+
 def _parser_add_ctc_control(parser, default=5):
     parser.add_argument("-cc", "--ctc_control", type=_int_or_float_type,
                         help="Control the number of reported contacts. "
@@ -386,6 +416,13 @@ def _parser_add_guess(parser):
                         help="Try not to be interactive. This can make wrong choices for the user, advanced only.")
     parser.set_defaults(accept_guess=False)
 
+def _parser_add_naive_bonds(parser):
+    parser.add_argument('--naive_bonds', "-nb", dest='naive_bonds', action='store_true',
+                        help="Build naive, linear bonds between protein residues "
+                             "of the same fragment if mdtraj can't build them automatically. "
+                             "For more info check mdciao.utils.bonds.top2residue_bond_matrix_naive ")
+    parser.set_defaults(naive_bonds=False)
+
 # TODO group the parser better!
 # TODO add short versions of the most frequent options
 def parser_for_rn():
@@ -432,7 +469,7 @@ def parser_for_rn():
     _parser_add_output_desc(parser, default='neighborhood')
     _parser_add_t_unit(parser)
     _parser_add_curve_color(parser)
-    _parser_add_gray_backgroud(parser)
+    _parser_add_background(parser)
     _parser_add_graphic_dpi(parser)
     _parser_add_short_AA_names(parser)
     _parser_add_no_fragfrag(parser)
@@ -446,6 +483,8 @@ def parser_for_rn():
     _parser_add_guess(parser)
     _parser_add_switch(parser)
     _parser_add_atomtypes(parser)
+    _parser_add_naive_bonds(parser)
+    _parser_add_scheme(parser)
     return parser
 
 def _parser_add_switch(parser):
@@ -500,7 +539,7 @@ def parser_for_dih():
     _parser_add_output_desc(parser, default='dih')
     _parser_add_t_unit(parser)
     _parser_add_curve_color(parser)
-    _parser_add_gray_backgroud(parser)
+    _parser_add_background(parser)
     _parser_add_graphic_dpi(parser)
     _parser_add_short_AA_names(parser)
     _parser_add_time_traces(parser)
@@ -539,7 +578,7 @@ def parser_for_sites():
     _parser_add_t_unit(parser)
     _parser_add_graphic_ext(parser)
     _parser_add_curve_color(parser)
-    _parser_add_gray_backgroud(parser)
+    _parser_add_background(parser)
     _parser_add_graphic_dpi(parser)
     _parser_add_ylim_Ang(parser)
     _parser_add_short_AA_names(parser)
@@ -564,7 +603,7 @@ def parser_for_interface():
                                           'To help in the identification of these two groups of residues, '
                                           'the peptide-chain in the input topology '
                                           'can be automatically broken down into fragments and use them as input. '
-                                          'The number of shown contacts depends on the parameters "n_ctcs" and '
+                                          'The number of shown contacts depends on the parameters "ctc_control" and '
                                           '"min_freq". ')
 
     _parser_add_fragments(parser)
@@ -579,9 +618,9 @@ def parser_for_interface():
     _parser_add_cutoff(parser)
     _parser_add_ctc_control(parser, default=50)
     parser.add_argument("-mf", "--min_freq", type=float, default=.05,
-                        help="Do not show frequencies smaller than this. If you notice the output being"
-                             "truncated a values too far away from this, you need to increase the"
-                             "'n_ctcs' parameter" )
+                        help="Do not show frequencies smaller than this. Default is 0.05. If you notice the output being "
+                             "truncated at values much larger than this, but suspect that some contacts "
+                             "are not being reported, increase the 'ctc_control' parameter")
     parser.add_argument("-ic", "--interface_cutoff_Ang", type=float,
                         help="The interface between both groups is defined as the set of group_1-group_2-"
                              "distances that are within this "
@@ -610,7 +649,7 @@ def parser_for_interface():
     _parser_add_graphic_dpi(parser)
     _parser_add_curve_color(parser)
     _parser_add_t_unit(parser)
-    _parser_add_gray_backgroud(parser)
+    _parser_add_background(parser)
     _parser_add_short_AA_names(parser)
     parser.add_argument('--no-sort_by_av_ctcs', dest='sort_by_av_ctcs', action='store_false',
                         help="When presenting the results summarized by residue, "
@@ -666,7 +705,8 @@ def parser_for_GPCR_overview():
                              "If a file is not found locally, look for\n"
                              " Ballesteros-Weinstein definitions in the GPCRdb\n"
                              "using this string as uniprot code, "
-                             "e.g. adrb2_human. See https://gpcrdb.org/services/ for more details."
+                             "e.g. adrb2_human. See https://gpcrdb.org/services/ for more details.",
+                        action=Populate_input_Action
                         )
     parser.add_argument("-t",'--topology', type=str, help='Topology file', default=None)
 
@@ -712,11 +752,45 @@ def parser_for_CGN_overview():
 
     return parser
 
+def parser_for_KLIFS_overview():
+    parser = argparse.ArgumentParser(description="Produce an overview of a the Kinase 85 pocket-residues nomenclature,"
+                                                 "optionally mapping it on an input topology. "
+                                                 "This nomenclature can be read locally or over the network from the "
+                                                 "KLIFS database." )
+
+    parser.add_argument("UniProtAC_or_excelfile", type=str,
+                        help="Get KLIFS definitions from here. A UniProt accession code, "
+                             "e.g. P31751 or a path to a an Excel File 'KLIFS_P31751.xlsx'."
+                             "If nothing is found locally, there will be a web-lookup "
+                             "in KLIFS, see https://klifs.net .",
+                        action=Populate_input_Action,
+                             )
+    parser.add_argument("-t", '--topology', type=str, help='Topology file', default=None)
+
+    _parser_add_write_to_disk(parser)
+    _parser_add_print_conlab(parser)
+    #_parser_add_fill_gaps(parser)
+    _parser_add_AAs(parser)
+    _parser_add_conslabels(parser)
+
+    return parser
+
 def parser_for_compare_neighborhoods():
     parser = argparse.ArgumentParser(description="Compare residue-residue contact frequencies "
-                                                 "from different files by generating a comparison plot and table")
+                                                 "from different files by generating a comparison plot and table",
+                                     formatter_class=SmartFormatter
+                                     )
     parser.add_argument("files", type=str, nargs="+",
-                        help="Files (ASCII or .xlsx) containing the frequencies and labels in the first columns")
+                        help="R|Files (ASCII or .xlsx) containing the frequencies \n"
+                             "and labels in the first two or three columns. Minimal examples \n"
+                             "could be :\n"
+                             ">>> #freq     label\n"
+                             ">>> 1.        GLU30-ALA50\n"
+                             ">>> .75       ALA50-ASP40\n"
+                             "or\n"
+                             ">>> 1.        GLU30 ALA50\n"
+                             ">>> .75       ALA50 ASP40\n"
+                             "Lines startint with '#' are ignored")
     parser.add_argument("-a","--anchor",type=str,default=None,
                         help="A residue that appears in all contacts. "
                              "It will be eliminated from the labels for clarity.")
@@ -784,7 +858,7 @@ def parser_for_residues():
     _parser_add_nomenclature(parser)
     _parser_add_topology(parser)
     _parser_add_guess(parser)
-    _parser_add_fragments(parser)
+    _parser_add_fragments(parser) #todo check why the formatting is off here but not in parser for rn
     return parser
 
 
