@@ -27,6 +27,8 @@ from matplotlib import \
     pyplot as _plt, \
     cm as _cm
 
+from matplotlib.colors import is_color_like as _is_color_like
+
 from mpl_toolkits.axes_grid1 import \
     make_axes_locatable as _make_axes_locatable
 
@@ -36,12 +38,15 @@ from os import path as _path
 
 from collections import defaultdict as _defdict
 
+import mdtraj as _md
+
 def plot_w_smoothing_auto(ax, y,
                           label,
                           color,
                           x = None,
-                          gray_background=False,
-                          n_smooth_hw=0):
+                          background=True,
+                          n_smooth_hw=0,
+                          ls="-"):
     r"""
     A wrapper around :obj:`matplotlib.pyplot.plot` that allows
     to add a smoothing window (or not). See
@@ -60,21 +65,30 @@ def plot_w_smoothing_auto(ax, y,
     x : iterable of floats, default is None
         If not provided, will default to
         x = _np.arange(len(y))
-    gray_background : bool, default is False
-        If True, instead of using a fainted version
-        of :obj:`color`, the original :obj:`y`
-        will be plotted in gray
-        (useful to avoid over-coloring plots)
+    background : bool, or color-like, (str, hex, rgb), default is True
+        When smoothing, the original curve can
+        appear in the background in different colors
+        * True:  use a fainted version of :obj:`color`
+        * False: don't plot any background
+        * color-like: use this color for the background,
+          can be: str, hex, rgba, anything
+          :obj:`matplotlib.pyplot.colors` understands
     n_smooth_hw : int, default is 0
         Half-size of the smoothing window.
         If 0, this method is identical to
         :obj:`matplotlib.pyplot.plot`
+    ls : str, default is "-"
+        The linestyle of the line, one of
+        [-', '--', '-.', ':', ''], more info
+        here for :obj:`matplotlib.lines.line2D`
 
     Returns
     -------
-    None
+    Line2D : :obj:`matplotlib.pyplot.Line2D`
+        The 2D smoothed line
 
     """
+    line2D = None
     alpha = 1
     if x is None:
         x = _np.arange(len(y))
@@ -82,18 +96,28 @@ def plot_w_smoothing_auto(ax, y,
         alpha = .2
         x_smooth = _mdcu.lists.window_average_fast(_np.array(x), half_window_size=n_smooth_hw)
         y_smooth = _mdcu.lists.window_average_fast(_np.array(y), half_window_size=n_smooth_hw)
-        ax.plot(x_smooth,
-                y_smooth,
-                label=label,
-                color=color)
+        line2D = ax.plot(x_smooth,
+                         y_smooth,
+                         label=label,
+                         color=color,
+                         ls=ls)[0]
         label = None
 
-        if gray_background:
-            color = "gray"
-    ax.plot(x, y,
-            label=label,
-            alpha=alpha,
-            color=color)
+        if background:
+            if isinstance(background,bool):
+                pass
+            else:
+                assert _is_color_like(background), "The argument 'background' has to be boolean (True/False) or color-like, but '%s' (%s) is neither"%(background, type(background))
+                color = background
+
+    _line2D = ax.plot(x, y,
+                      label=label,
+                      alpha=alpha,
+                      color=color)[0]
+    if line2D is None:
+        line2D = _line2D
+
+    return line2D
 
 def compare_groups_of_contacts(groups,
                                colors=None,
@@ -128,9 +152,10 @@ def compare_groups_of_contacts(groups,
           * dictionaries where the keys are residue-pairs
           (one letter-codes, no fragment info, as in :obj:`ContactGroup.ctc_labels_short`)
           and the values are contact frequencies [0,1]
-          * ascii-files (see :obj:`freq_datfile2freqdict`)
-            with the contact labels in the second and frequencies in
-            the third column
+          * ascii-files with the contact the frequencies in the first
+            column and labels in the second and/or third column,
+            see :obj:`~mdciao.contacts.ContactGroup.frequency_str_ASCII_file`
+            and :obj:`~mdciao.utils.str_and_dict.freq_ascii2dict`
           * .xlsx files with the header in the second row,
             containing at least the column-names "label" and "freqs"
 
@@ -198,7 +223,7 @@ def compare_groups_of_contacts(groups,
         Instead of plotting contact frequencies,
         plot contact distributions
     interface : bool, default is False
-        As if per_residue=True and
+        Asks if per_residue=True and
         then sorts the residues into
         interface fragments. Will fail
         if the passed :obj:`groups`
@@ -234,7 +259,7 @@ def compare_groups_of_contacts(groups,
         assert all([igroup.is_interface for igroup in groups.values()])
 
     freqs = {key: {} for key in groups.keys()}
-    colors = _color_dict_guesser(colors, freqs.keys())
+    colors = color_dict_guesser(colors, freqs.keys())
 
     for key, ifile in groups.items():
         if isinstance(ifile, str):
@@ -245,7 +270,7 @@ def compare_groups_of_contacts(groups,
                                                  split_label=False,
                                                  bins=_np.max([20, (_np.sqrt(ifile.n_frames_total) / 2).round().astype(int)]))
             else:
-                assert ctc_cutoff_Ang is not None, "Cannot provide a ContatGroup object without a ctc_cutoff_Ang parameter"
+                assert ctc_cutoff_Ang is not None, "Cannot provide a ContatGroup object without a `ctc_cutoff_Ang` parameter"
                 if not interface:
                     idict = ifile.frequency_dicts(ctc_cutoff_Ang=ctc_cutoff_Ang,
                                               AA_format=AA_format,
@@ -303,7 +328,7 @@ def compare_groups_of_contacts(groups,
         freqs = _mdcu.str_and_dict.unify_freq_dicts(freqs, exclude,
                                             per_residue=[per_residue if not interface else False][0],
                                             defrag=defrag)
-        if per_residue:
+        if per_residue or interface:
             kwargs_plot_unified_freq_dicts["ylim"]= _np.max([_np.max(list(ifreqs.values())) for ifreqs in freqs.values()])
             kwargs_plot_unified_freq_dicts["remove_identities"] = False
 
@@ -327,26 +352,36 @@ def compare_groups_of_contacts(groups,
 
     return myfig, freqs, plotted_freqs
 
-def _color_dict_guesser(colors, key_list):
+def color_dict_guesser(colors, keys):
     r"""
-    Helper function to construct a color dictionary from variable user input
+    Helper function to construct a color dictionary from user input
 
     Parameters
     ----------
     colors : None, str, list or dict
-        * None: use the first len(key_list) "tab10" colors
-        * str: name of the matplotlib colormap to interpolate to len(key_list) colors
+        * None: use the first :obj:`n` "tab10" colors, where
+          n is determined by :obj:`keys`
+        * str: name of the matplotlib colormap to interpolate to :obj:`n` colors.
+          Can be qualitative like "Set2" or "tab20" or
+          quantitative like "viridis" or "Reds". For more info see:
           https://matplotlib.org/stable/tutorials/colors/colormaps.html
         * list: list of colors (["r","g","b"])
-          Turn this list into a dictionary keyed with :ob:`key_list`
-    key_list : list
-        List of strings to use as keys for the
-        color dictionary that will be ultimately returned
+          Turn this list into a dictionary keyed with :obj:`keys`
+    keys : int or list
+        If int, create a list of keys = _np.arange(keys).
+        If list, use that list directly as keys for the
+        color dictionary that will be returned
 
     Returns
     -------
     colors : dict
     """
+    if isinstance(keys, int):
+        assert keys>0, ("If integer,'keys' has to be > 0 ")
+        key_list = _np.arange(keys)
+    else:
+        key_list = keys
+
     if isinstance(colors,dict):
         assert all([key in colors.keys() for key in key_list])
     elif colors is None:
@@ -355,6 +390,8 @@ def _color_dict_guesser(colors, key_list):
         if _is_colormapstring(colors):
             return {key: color for key, color in zip(key_list,_try_colormap_string(colors,len(key_list)))}
         else:
+            assert any([_is_color_like(colors), all([_is_color_like(char) for char in colors])]),\
+                ValueError("'%s' is neither a matplotlib colormap, nor a matplotlib color, nor exclusively made up from valid matplotlib one-letter color-codes 'bcgkmrwy'"%colors)
             return {key:colors for key in key_list}
 
     if isinstance(colors, list):
@@ -627,6 +664,7 @@ def plot_unified_freq_dicts(freqs,
         [idict.pop(ctc) for idict in freqs_by_sys_by_ctc.values()]
         all_ctc_keys.remove(ctc)
 
+    ylim = _np.max([ylim, _np.ceil(_np.hstack([list(val.values()) for val in freqs_by_sys_by_ctc.values()]).max())])
     # Prepare the dict that stores the order for plotting
     # and the values used for that sorting
     sorted_value_by_ctc_by_sys = {key: val for (key, val) in
@@ -721,7 +759,8 @@ def plot_unified_freq_dicts(freqs,
         _plt.xlim(0, ylim)
         _plt.ylim(0 - width, ii + width * len(freqs_by_sys_by_ctc))
         _plt.xticks([0, .25, .50, .75, 1])
-        [_plt.gca().axvline(ii, ls=":", color="k", zorder=-1) for ii in [.25, .5, .75]]
+        ax.grid(axis="x", ls=":", color="k", zorder=-10)
+        ax.set_axisbelow(True)
         _plt.gca().invert_yaxis()
 
         if sort_by == "std":
@@ -756,7 +795,8 @@ def plot_unified_freq_dicts(freqs,
         else:
             yticks = _np.arange(0,_np.ceil(ylim),.50)
         _plt.yticks(yticks)
-        [_plt.gca().axhline(ii, ls=":", color="k", zorder=-1) for ii in yticks[1:-1]]
+        ax.grid(axis="y", ls=":", color="k", zorder=-10)
+        ax.set_axisbelow(True)
         if sort_by == "std":
             _plt.plot(list(sorted_value_by_ctc_by_sys.values()),
                       color='k', alpha=.25, ls=':')
@@ -916,7 +956,7 @@ def plot_unified_distro_dicts(distros,
     distros_by_ctc_by_sys = dict(distros_by_ctc_by_sys)
 
     # Prepare the dict
-    colors = _color_dict_guesser(colors,system_keys)
+    colors = color_dict_guesser(colors, system_keys)
 
     n_cols = _np.min((n_cols, len(all_ctc_keys)))
     n_rows = _np.ceil(len(all_ctc_keys) / n_cols).astype(int)
@@ -958,27 +998,46 @@ def compare_violins(groups,
                     colors=None,
                     ctc_cutoff_Ang=None,
                     fontsize=16,
-                    figsize=(10,7),
                     mutations_dict={},
                     legend_rows=4,
                     AA_format='short',
                     defrag='@',
                     anchor=None,
                     ymax=None,
+                    key_separator="-",
+                    sort_by="mean",
+                    figsize=None,
+                    panelheight_inches=5,
+                    inch_per_contacts=1,
+                    zero_freq = 1e-2,
+                    remove_identities=False,
+                    identity_cutoff=1,
+                    representatives=None,
                     ):
     r"""
-    Plot all distance-distributions several :obj:`~mdciao.contacts.ContactGroup` s together using :obj:`~matplotlib.pyplot.violinplot` s
+    Plot all distance-distributions of several :obj:`~mdciao.contacts.ContactGroup` s together using :obj:`~matplotlib.pyplot.violinplot` s
+
+    Contacts across different :obj:`groups` are grouped together by
+    matching their contact labels, since the residue indices
+    might differ across :obj:`groups`. To achieve this:
+        * "K30-D40" is considered equivalent to "D40-D30",
+          use :obj:`key_separator` to change this.
+        * "K30-D40" is considered equivalent to "K30-E40"
+          if a :obj:`mutations_dict={"E40":"D40"}` is passed
+        * "K30@3.50-D40" is considered equivalent to "K30-D40"
+          if you defragment your labels using :obj:`defrag="@"`
 
     Parameters
     ----------
-    groups : dictionary of :obj:`~mdciao.contacts.ContactGroup`-objects
-        The keys are the system/setup descriptors, e.g. "WT", "MUT" etc
+    groups : dictionary or list of :obj:`~mdciao.contacts.ContactGroup`-objects
+        The keys are the system/setup descriptors, e.g. "WT", "MUT" etc.
+        If list, keys will be generated on the fly "mdcCG 0, mdcCG 1..."
     colors : iterable (list or dict), or str, default is None
         * If list, the colors will be assigned in the same
           order of :obj:`groups`.
         * If dict, has to have the
           same keys as :obj:`groups`.
-        * If str, it has to be a case-sensitve colormap-name of matplotlib:
+        * If str, it has to be a case-sensitive colormap-name of matplotlib:
           https://matplotlib.org/stable/tutorials/colors/colormaps.html
         * If None, the 'tab10' colormap (tableau) is chosen
         TODO: I could set the default to "tab10", but then it'd
@@ -988,9 +1047,24 @@ def compare_violins(groups,
         at this distance value.
     fontsize : int, default is 16
         Will be used in :obj:`~matplotlib.rcParams` ["font.size"]
-    figsize : iterable of len 2
-        Figure size (x,y), in inches.
-        # TODO be less invasive
+    panelheight_inches : int, default is 5
+        The height of the panel, in inches.
+        Determines the figure size
+        if :obj:`figsize` is None,
+        else has no effect
+    inch_per_contacts : int, default is 1
+        How many inches each contact-pair
+        is given in the panel. Determines
+        the figure size if :obj:`figsize` is None,
+        else has no effect
+    figsize : None or iterable of len 2, default is None
+        Figure size (x,y), in inches. If None,
+        one will be created using :obj:`panelheight_inches`
+        and :obj:`inch_per_contacts`.
+        If you are transposing the figure
+        using :obj:`vertical_plot`, you do not
+        have to invert (y,x) this parameter here, it is
+        done automatically.
     mutations_dict : dictionary, default is {}
         A mutation dictionary that contains allows to plot together
         residues that would otherwise be identified as different
@@ -1015,63 +1089,225 @@ def compare_violins(groups,
     ymax : float, default is None
         Maximum value of the y-axis,
         default is to set it automatically
+    key_separator : str, default is "-"
+        How each contact label separates
+        the pair of residues, "ALA50-GLU30".
+        If you set this to None, it means
+        the label won't be separated before
+        matching and "ALA50-GLU30" will be
+        different from "GLU30-ALA50".
+    sort_by : str or list, default is 'mean'
+        By default, the violins are sorted
+        by ascending order of mean distance, i.e.
+        from most "formed" on the left of the plot
+        to least "formed" on the right of the plot.
+        However, for each residue pair, this mean is
+        an average over the distance in all
+        the different :obj:`groups`, so some
+        heterogeneity is expected. Alternatively,
+        you can sort using the contact labels,
+        regardless of the distance values. Note
+        that for this, string comparisons between
+        contact-labels will take place. and that
+        contact-labels are altered by :obj:`key_separator`
+        to unify across different :obj:`groups`
+        Try setting :obj:`key_separator` to None
+        if you see unexpected behavior, although
+        though this might have other side effects,
+        (see obj:~`mdciao.utils.str_and_dict.unify_freq_dicts`)
+        :obj:`sort_by` can be a:
+            * str : 'residue'
+              Sort by ascending residue sequence index (resSeq),
+              which will be inferred from each contact label,
+              e.g. 30 for "GLU30@3.50". See :obj:`~mdciao.contacts.ContactGroup.gen_ctc_labels`
+              for more info on how they are generated.
+              Internally, the order is generated via
+              :obj:`~mdciao.utils.str_and_dict.lexsort_ctc_labels`.
+              If you want to reverse or alter this
+              ascending default order, we recommend using
+              :obj:`~mdciao.utils.str_and_dict.lexsort_ctc_labels`
+              **before** calling :obj:`compare_violins` and use
+              its output (sorted_ctc_labels) as a list
+              argument for :obj:`sort_by`. Also note that
+              residue indices as contained in
+              :obj:`~mdciao.contacts.ContactGroup.res_idx_pairs`
+            * list : a list of contact labels,
+              eg. ["GLU30-ALA30", "ARG131@3.50-TYR20"].
+              Only these residue pairs (in this order)
+              will be shown, regardless of what other
+              pairs are contained in the :obj:`groups`. It
+              assumes the user knows what contacts
+              are present and can come up with a meaningful
+              list. Not all labels need to be in all
+              :obj:`groups` nor do all :obj:`groups`
+              have to contain all labels, but at least
+              one label needs to match, otherwise the
+              method will fail
+    zero_freq : float, default is 1e-2
+        Frequencies below this number will
+        be considered zero and not shown it they are
+        zero for the same residue pair across all :obj:`groups`
+        For this parameter to have effect, you need a
+        :obj:`ctc_cutoff_Ang`
+    remove_identities : bool, default is False
+        If True, the contacts where
+        freq[sys][ctc] >= :obj:`identity_cutoff`
+        across all systems will not be plotted
+        nor considered in the sum over contacts
+    identity_cutoff : float, default is 1
+        If :obj:`remove_identities`, use this value to define what
+        is considered an identity, s.t. contacts with values e.g. .95
+        can also be removed
+    representatives : anything (bool, int, dict, list) default is None
+        Plot, with a small dot on top of the violins,
+        the values of the residue-residue distances of representative
+        geometries. The representative geometries can be parsed
+        directly as a dict of :obj:`~mdtraj.Trajectory` objects,
+        or extracted on-the-fly by calling the :obj:`mdciao.contacts.ContactGroup.repframes`
+        method of each of the `groups`. Check the docs of
+        :obj:`mdciao.contacts.ContactGroup.repframes` to find out what is meant
+        with "representative".
+        This is what each type of input does:
+
+        * boolean True:
+          Calls :obj:`mdciao.ContactGroup.repframes` with the
+          method's default parameters and plots the result
+        * int > 0:
+          Calls :obj:`mdciao.ContactGroup.repframes` with the
+          parameter `n_frames` set to this integer. This parameter
+          controls how many representatives are extracted and
+          subsequently plotted.
+        * dict of parameters:
+          A dictionary with explict values for the optional
+          parameters of :obj:`mdciao.contacts.ContactGroup.repframes`,
+          usually `n_frames` (an int) and `scheme`, ("mean" or "mode"),
+          depending what you mean with "representative". Check the method's
+          documentation for more info.
+        * dict of :obj:`~mdtraj.Trajectory` objects:
+          Has to have the same keys as `groups`. No checks are done
+          whether these objects match the actual molecular topologies
+          of `groups`, so beware of potential mismatches here.
+          Typically, these frames come from having used
+          :obj:`mdciao.contacts.ContactGroup.repframes` with
+          `return_traj`=True.
+        * dict of dicts containing values
+          #TODO not implemented yet
 
     Returns
     -------
     fig : :obj:`~matplotlib.figure.Figure`
     ax :  :obj:`~matplotlib.axes.Axes`
+    labels : list
+        The list of plotted labels,
+        in the order they are plotted
     """
     _fontsize=_rcParams["font.size"]
     _rcParams["font.size"] = fontsize
 
     # Gather data
-    data4violins_per_sys_per_ctc={}
-    for syskey, group in groups.items():
+    data4violins_per_sys_per_ctc = {}
+    freqs_per_sys_per_ctc = {}
+    if isinstance(groups,list):
+        _groups = {"mdcCG %u" % ii : item for ii, item in enumerate(groups)}
+    else:
+        _groups = groups
+    repframes_per_sys_per_ctc = {}
+    for syskey, group in _groups.items():
         labels = group.gen_ctc_labels(AA_format=AA_format,
                                       fragments=[True if defrag is None else False][0],
                                       )
         idict = {key : _np.hstack(cp.time_traces.ctc_trajs) * 10
                  for key, cp in zip(labels, group._contacts)}
-        #TODO avoid repetition
-        if anchor is not None:
-            idict, deleted_half_keys = _mdcu.str_and_dict.delete_exp_in_keys(idict, anchor)
-            if len(_np.unique(deleted_half_keys))>1:
-                raise ValueError("The anchor patterns differ by key, this is strange: %s"%deleted_half_keys)
-            else:
-                anchor=_mdcu.str_and_dict.defrag_key(deleted_half_keys[0],defrag=defrag,sep=" ")
         data4violins_per_sys_per_ctc[syskey] = idict
+        if ctc_cutoff_Ang is not None:
+            freqs_per_sys_per_ctc[syskey] = {key:freq for key, freq in zip(labels, group.frequency_per_contact(ctc_cutoff_Ang))}
 
-    # Unify it
+        if bool(representatives):
+            # Do we have representatives?
+            if isinstance(representatives, bool):
+                d = group.repframes(ctc_cutoff_Ang=ctc_cutoff_Ang)[2]
+            if isinstance(representatives, int) and representatives>0:
+                d = group.repframes(ctc_cutoff_Ang=ctc_cutoff_Ang, n_frames=representatives)[2].T
+            if isinstance(representatives, dict) and len(representatives)>0:
+                if syskey not in representatives.keys() :
+                    representatives.pop("ctc_cutoff_ang", None)
+                    representatives.pop("show_violins", None)
+                    d = group.repframes(**representatives)[2].T
+                else:
+                    assert isinstance(representatives[syskey], _md.Trajectory)
+                    d = _md.compute_contacts(representatives[syskey], contacts=group.res_idxs_pairs)[0].T
+            repframes_per_sys_per_ctc[syskey] = {key: val * 10 for key, val in
+                                                 zip(labels, d)}
+
+    representatives = bool(representatives)
+    # Unify data
     data4violins_per_sys_per_ctc = _mdcu.str_and_dict.unify_freq_dicts(data4violins_per_sys_per_ctc,
                                                                        replacement_dict=mutations_dict,
                                                                        is_freq=False,
-                                                                       val_missing=_np.nan)
+                                                                       val_missing=_np.nan,
+                                                                       key_separator=key_separator) #todo use kwargs?
+    if representatives:
+        repframes_per_sys_per_ctc = _mdcu.str_and_dict.unify_freq_dicts(repframes_per_sys_per_ctc,
+                                                                        replacement_dict=mutations_dict,
+                                                                        is_freq=False,
+                                                                        val_missing=_np.nan,
+                                                                        key_separator=key_separator)
+
+    # Delete some keys if all freqs are < zero_freq
+    if ctc_cutoff_Ang is not None:
+        # First unify
+        freqs_per_sys_per_ctc = _mdcu.str_and_dict.unify_freq_dicts(freqs_per_sys_per_ctc,
+                                                                    replacement_dict=mutations_dict,
+                                                                    is_freq=True,
+                                                                    val_missing=0,
+                                                                    verbose=False,
+                                                                    key_separator=key_separator)  # todo use kwargs?
+        #Since the dict is unified, we can do this
+        _freq_dict = _defdict(list)
+        for idict in freqs_per_sys_per_ctc.values():
+            for key, freq in idict.items():
+                _freq_dict[key].append(freq)
+        pop_from_below = [key for key, ifreqs in _freq_dict.items() if all([ifreq < zero_freq for ifreq in ifreqs])]
+        pop_from_above = [key for key, ifreqs in _freq_dict.items() if all([ifreq >= identity_cutoff for ifreq in ifreqs])]
+        [[idict.pop(key) for idict in data4violins_per_sys_per_ctc.values()] for key in pop_from_below]
+        if remove_identities:
+            [[idict.pop(key) for idict in data4violins_per_sys_per_ctc.values()] for key in pop_from_above]
+
+    # TODO avoid repetition
+    if anchor is not None:
+        for key, idict in data4violins_per_sys_per_ctc.items():
+            data4violins_per_sys_per_ctc[key], deleted_half_keys = _mdcu.str_and_dict.delete_exp_in_keys(idict, anchor)
+        if len(_np.unique(deleted_half_keys)) > 1:
+            raise ValueError("The anchor patterns differ by key, this is strange: %s" % deleted_half_keys)
+
+        if representatives is not {}:
+            for key, idict in repframes_per_sys_per_ctc.items():
+                repframes_per_sys_per_ctc[key], deleted_half_keys = _mdcu.str_and_dict.delete_exp_in_keys(idict,
+                                                                                                          anchor)
+            if len(_np.unique(deleted_half_keys)) > 1:
+                raise ValueError("The anchor patterns differ by key, this is strange: %s" % deleted_half_keys)
+
     # Gather keys
-    all_sys_keys = list(groups.keys())
+    all_sys_keys = list(_groups.keys())
     all_ctc_keys = list(data4violins_per_sys_per_ctc[all_sys_keys[0]])
     data4violins_per_ctc_per_sys = {key:{sk:data4violins_per_sys_per_ctc[sk][key] for sk in all_sys_keys} for key in all_ctc_keys}
-    means_per_ctc_per_sys = {key:_np.nanmean(_np.hstack(list(val.values()))) for key, val in data4violins_per_ctc_per_sys.items()}
+    means_per_ctc_across_sys = {key:_np.nanmean(_np.hstack(list(val.values()))) for key, val in data4violins_per_ctc_per_sys.items()}
 
     # Prepare the dict
-    colordict = _color_dict_guesser(colors, all_sys_keys)
-
-    sorting_idxs = _np.argsort(list(means_per_ctc_per_sys.values()))
-    key2ii = {all_ctc_keys[idx]: ii for ii, idx in enumerate(sorting_idxs)}
-    delta, width = _offset_dict(list(groups.keys()))
+    colordict = color_dict_guesser(colors, all_sys_keys)
+    sorted_keys = _key_sorter(sort_by, means_per_ctc_across_sys)
+    key2ii = {key : ii for ii, key in enumerate(sorted_keys)}
+    delta, width = _offset_dict(list(_groups.keys()))
 
+    if figsize is None:
+        figsize=(len(key2ii)*inch_per_contacts, panelheight_inches)
     myfig = _plt.figure(figsize=figsize)
     iax = _plt.gca()
-    """
-    for ctc_key, ii in key2ii.items():
-        iax.plot(ii, means_per_ctc_per_sys[ctc_key],"ok")
-        for syskey,sysdata_per_ctc in data4violins_per_sys_per_ctc.items():
-            iax.plot(ii+delta[syskey],_np.nanmean(sysdata_per_ctc[ctc_key]),"x", color=colordict[syskey])
-    """
-
     _add_grey_banded_bg(_plt.gca(), len(all_ctc_keys))
+
     for syskey in all_sys_keys:
-        positions = [key2ii[key]+delta[syskey] for key, val in data4violins_per_sys_per_ctc[syskey].items() if not val is _np.nan]
-        idata = [val for val in data4violins_per_sys_per_ctc[syskey].values() if val is not _np.nan]
+        positions = [key2ii[key]+delta[syskey] for key, val in data4violins_per_sys_per_ctc[syskey].items() if val is not _np.nan and key in key2ii.keys()]
+        idata = [val for key, val in data4violins_per_sys_per_ctc[syskey].items() if val is not _np.nan and key in key2ii.keys()]
         violins = _plt.violinplot(idata, positions=positions,
                                   widths=width,
                                   showmeans=True,
@@ -1083,6 +1319,12 @@ def compare_violins(groups,
         _plt.plot(_np.nan, _np.nan, "d",color=colordict[syskey],
                   #alpha=vio.get_alpha()*1.5,
                   label=syskey)
+        if representatives:
+            irep = _np.vstack([val for key, val in repframes_per_sys_per_ctc[syskey].items() if val is not _np.nan and key in key2ii.keys()])
+            _plt.plot(positions, irep, "o ",
+                      ms=2.5,
+                      color=colordict[syskey]
+                      )
 
     # Cosmetics
     if defrag is None:
@@ -1095,25 +1337,67 @@ def compare_violins(groups,
 
     if ctc_cutoff_Ang is not None:
         iax.axhline(ctc_cutoff_Ang, color="gray",ls="--", zorder=-10)
-    _plt.xticks(_np.arange(len(all_ctc_keys)),[prepare_str(all_ctc_keys[ii]) for ii in sorting_idxs],
+    _plt.xticks(_np.arange(len(key2ii)),[prepare_str(key) for key in key2ii.keys()],
                 rotation=45,
                 va="top",
-                ha="right"
+                ha="right",
+                rotation_mode="anchor"
                 )
-    iax.set_xlim([0-.5,len(all_ctc_keys)-.5])
+    iax.set_xlim([0-.5,len(key2ii)-.5])
     iax.set_ylabel("D / $\AA$")
     if ymax is not None:
         iax.set_ylim([iax.get_ylim()[0], ymax])
 
-
-    iax.legend(ncol=_np.ceil(len(all_sys_keys) / legend_rows).astype(int),loc="upper left")
+    iax.legend(ncol=_np.ceil(len(all_sys_keys) / legend_rows).astype(int),
+               #loc="upper left"
+               )
     myfig.tight_layout()
 
-
     _rcParams["font.size"] = _fontsize
-    return myfig, iax
+    return myfig, iax, list(key2ii.keys())
 
 
+def _key_sorter(sort_by, indict):
+    r"""
+    Helper method to sort the keys of a dictionary according to some rules
+
+    Parameters
+    ----------
+    sort_by : str or list
+        Currently, can be
+        * "residue", i.e. sort the dict
+           by the resSeq of the contact labels
+        * "value", i.e. sort the dict
+           by the values of the :obj:`indict`
+        * list, i.e. sort the dict
+          following this list, i.e.
+          return the intersection
+          of this list with the dict's keys
+    indict : dict
+        The dictionary to be
+        sorted according to
+        some :obj:`sort_by` criterion.
+        It's assumed that the keys
+        are contact labels with
+        "-" as the separator
+    Returns
+    -------
+    ordered_keys : list
+        The list of sorted keys
+    """
+    all_ctc_keys= list(indict.keys())
+    if isinstance(sort_by, str) and sort_by == "residue":
+        ordered_keys = _mdcu.str_and_dict.lexsort_ctc_labels(all_ctc_keys)[0]
+    elif isinstance(sort_by, str) and sort_by == "mean":
+        ordered_keys = list(_mdcu.str_and_dict.sort_dict_by_asc_values(indict).keys())
+    elif isinstance(sort_by, list):
+        assert set(sort_by).intersection(all_ctc_keys), ("The 'sort_by' list '%s' doesn't contain any of the available contact pairs '%s'"%(sort_by, all_ctc_keys))
+        ordered_keys = [key for key in sort_by if key in all_ctc_keys]
+    else:
+        raise ValueError("Argument 'sort_by' has to be either 'residue', 'mean', or list (contact labels) not '%s'"%sort_by)
+
+    return ordered_keys
+
 def add_tilted_labels_to_patches(jax, labels,
                                  label_fontsize_factor=1,
                                  trunc_y_labels_at=.65,
@@ -1614,4 +1898,50 @@ def _plot_violin_baseplot(vdata,
     violins["cmeans"].set_color(colors)
     for vio,col in zip(violins["bodies"],colors):
         vio.set_color(col)
-    return jax, violins
\ No newline at end of file
+    return jax, violins
+
+def _color_tiler(colors, n):
+    r"""
+    Tile colors up to n individual colors, related flare._utils.tocol_list_from_input_and_fragments
+
+    This is how it works
+
+    >>> plots._color_tiler("red",5)             #pure str
+    >>> ['red', 'red', 'red', 'red', 'red']
+
+    >>> plots._color_tiler(["red"],5)           # list of str with 1 item
+    >>> ['red', 'red', 'red', 'red', 'red']
+
+    >>> plots._color_tiler(["red", "blue"], 5)  # list of strs
+    >>> ['red', 'blue', 'red', 'blue', 'red']
+
+    >>> plots._color_tiler([[1., 0., 0.],       # red
+    >>>                     [0., 1., 0.],       # green
+    >>>                     [0., 0., 1.]], 5)   # blue
+    >>> [[1.0, 0.0, 0.0],
+    >>>  [0.0, 1.0, 0.0],
+    >>>  [0.0, 0.0, 1.0],
+    >>>  [1.0, 0.0, 0.0],
+    >>>  [0.0, 1.0, 0.0]]
+
+    Parameters
+    ----------
+    colors : str, list, array
+        Color input to be tiled up to :ob:`n` colors
+        using :obj:`numpy.tile`, e.g.
+    n : int
+        The number of needed colors
+
+    Returns
+    -------
+    tiled_colors : list
+
+    """
+    if isinstance(colors,str):
+        tiled_colors = _np.tile(colors,  _np.ceil(n / 1).astype(int) )[:n]
+    elif _np.array(colors).ndim in [0,1]:
+        tiled_colors = _np.tile(colors,  _np.ceil(n / len(colors)).astype(int) )[:n]
+    else:
+        tiled_colors = _np.tile(colors, (_np.ceil(n / len(colors)).astype(int),1))[:n]
+
+    return tiled_colors.tolist()
\ No newline at end of file
