@@ -72,8 +72,8 @@ def residues_from_descriptors(residue_descriptors,
     """
     residxs = []
     fragidxs = []
-    last_answer = '0'
-
+    last_answer = None
+    first_run = True
 
     if isinstance(residue_descriptors, (str, int)):
         residue_descriptors = [residue_descriptors]
@@ -102,13 +102,13 @@ def residues_from_descriptors(residue_descriptors,
                 istr = residue_line("0.0", top.residue(residxs[-1]), fragidxs[-1], additional_resnaming_dicts, fragment_names=fragment_names)
                 print(istr)
         else:
-            istr = "ambiguous definition for AA %s" % key
+            istr = "Ambiguous definition for residue %s" % key
             istr += extra_string_info
             if not just_inform:
                 print(istr)
             cand_chars = _np.hstack([['%s.%u'%(key,ii) for ii in range(n)] for key, n in _Counter(cand_fragments).items()]).tolist()
             for cc, ss, char in zip(cands, cand_fragments, cand_chars):
-                istr = residue_line(char, top.residue(cc), ss, additional_resnaming_dicts)
+                istr = residue_line(char, top.residue(cc), ss, additional_resnaming_dicts, fragment_names=fragment_names)
                 print(istr)
             if just_inform:
                 print()
@@ -116,10 +116,16 @@ def residues_from_descriptors(residue_descriptors,
                 fragidxs.extend([ii for ii in cand_fragments if ii not in fragidxs])
                 continue
             if pick_this_fragment_by_default is None:
+                if first_run is True:
+                    last_answer = [int(ii) for ii in _np.unique(cand_fragments)][0]
+                    choice_str = "choose first candidate fragment [%s]" % last_answer
+                    first_run = False
+                else:
+                    choice_str = "repeat last option [%s]" % last_answer
                 prompt = "Input one fragment idx out of %s and press enter (selects all matching residues in that fragment).\n" \
                          "Use one x.y descriptor in case of repeated fragment index.\n" \
-                         "Leave empty and hit enter to repeat last option [%s]" % (
-                         [int(ii) for ii in _np.unique(cand_fragments)], last_answer)
+                         "Leave empty and hit enter %s" % (
+                         [int(ii) for ii in _np.unique(cand_fragments)], choice_str)
 
                 answer = input(prompt)
             else:
@@ -134,7 +140,7 @@ def residues_from_descriptors(residue_descriptors,
                 assert answer in cand_fragments
                 idxs_w_answer = _np.argwhere([answer == ii for ii in cand_fragments]).squeeze()
                 cands = cands[idxs_w_answer]
-            elif '.' in answer and answer in cand_chars:
+            elif '.' in str(answer) and answer in cand_chars:
                 idx_w_answer = _np.argwhere([answer == ii for ii in cand_chars]).squeeze()
                 answer = cand_fragments[idx_w_answer]
                 cands = cands[idx_w_answer]
