@@ -21,6 +21,8 @@ import numpy as _np
 from pandas import DataFrame as _DF
 from Bio.pairwise2 import align as _Bioalign
 from .lists import contiguous_ranges as _cranges
+import pandas as _pd
+from IPython.display import display as _display
 
 
 # See "Define original properties" https://pandas.pydata.org/pandas-docs/stable/development/extending.html#define-original-properties
@@ -73,10 +75,9 @@ def print_verbose_dataframe(df):
     -------
 
     """
-    import pandas as _pd
-    from IPython.display import display as _display
-    with _pd.option_context('display.max_rows', None,
-                            'display.max_columns', None,
+    rows, columns = df.shape
+    with _pd.option_context('display.max_rows', rows,
+                            'display.max_columns', columns,
                             'display.width', 1000):
         _display(df)
 
@@ -101,7 +102,7 @@ def top2seq(top, replacement_letter="X"):
 
 def my_bioalign(seq1, seq2,
                 method="globalms",
-                argstuple=(1,0,-1,0),
+                argstuple=(1,0,-1,-.05),
                 kwargs = {"penalize_end_gaps":False}):
     r"""
     Align two sequences using a method of :obj:`Bioalign`
@@ -110,13 +111,13 @@ def my_bioalign(seq1, seq2,
     ----
     This is a one-liner wrapper around whatever method
     of :obj:`Bioalign` has been chosen, typically
-    pairwise2.align.globalxs
+    pairwise2.align.globalms
 
     The intention is to only use *this* method throughout
     mdciao, and change *here* any alignment parameters s.t.
     alignment is done using *always* the same parameters.
 
-    The exposed arguments :obj:`method` and :obj:`argstuple`
+    The exposed arguments `method` and `argstuple`
     are there for future development but will raise
     NotImplementedErrors if changed.
 
@@ -127,9 +128,13 @@ def my_bioalign(seq1, seq2,
     ----------
     seq1 : str, any length
     seq2 : str, any length
-    method : str, default is "globalxs"
-    argstuple : tuple, default is (-1,0)
-        The
+    method : str, default is "globalms"
+    argstuple : tuple, default is (-1,0,-1,-.05)
+        The tuple controlling penalties for:
+        * matches
+        * mismatches
+        * opening a gap
+        * extending the gap
 
     Returns
     -------
@@ -140,9 +145,9 @@ def my_bioalign(seq1, seq2,
 
 
     """
-    # This is to be able to raise the NotImplemented but also to hard-code the only allowd method here
+    # This is to be able to raise the NotImplemented but also to hard-code the only allowEd method here
     allowed_method="globalms"
-    allowed_tuple = (1, 0, -1,0)
+    allowed_tuple = (1, 0, -1, -.05)
     if method!=allowed_method:
         raise (NotImplementedError("At the moment only %s is "
                                    "allowed as alignment method"%method))
@@ -481,7 +486,7 @@ def re_match_df(df):
                 if all(_df.loc[[rr[0] - 1, rr[-1] + 1]]["match"]) and \
                         all(["-" not in df[key].values[rr] for key in ["AA_0",
                                                                    "AA_1"]]):  # this checks for no insertions in the alignment ("=equal length ranges")
-                    _df.at[rr, "match"] = True
+                    _df.loc[rr, "match"] = True
             except KeyError:
                 continue
 
