@@ -154,6 +154,11 @@ def delete_pattern_in_ctc_label(pattern, label, sep):
     assert len(new_name) == 1, (new_name, pattern)
     return new_name[0], deleted_half_keys
 
+# Order key alphabetically using the separator_key
+def order_key(key, sep):
+    split_key = splitlabel(key,sep)
+    return sep.join([split_key[ii] for ii in _np.argsort(split_key)])
+
 def unify_freq_dicts(freqs,
                      exclude=None,
                      key_separator="-",
@@ -162,6 +167,7 @@ def unify_freq_dicts(freqs,
                      per_residue=False,
                      is_freq=True,
                      val_missing=0,
+                     verbose=True
                      ):
     r"""
     Provided with a dictionary of dictionaries, returns an equivalent,
@@ -208,6 +214,8 @@ def unify_freq_dicts(freqs,
     val_missing : anything, default is 0
         What value to assign to the
         missing keys (TODO check the name of this in pandas)
+    verbose : bool, default is True
+        Be verbose
 
 
     Returns
@@ -218,22 +226,17 @@ def unify_freq_dicts(freqs,
         B:{key1:0,     key2:valB2, key3:valB3}}
     """
 
-    # Order key alphabetically using the separator_key
-    def order_key(key, sep):
-        split_key = splitlabel(key,sep)
-        return sep.join([split_key[ii] for ii in _np.argsort(split_key)])
+    # Create a copy
+    freqs_work = {key : {key2: val for key2, val in idict.items()} for key, idict in freqs.items()}
 
-    # Create a copy, with re-ordered keys if needed
-    freqs_work = {}
-    for key, idict in freqs.items():
-        if str(key_separator).lower()=="none" or len(key_separator)==0:
-            freqs_work[key] = {key:val for key, val in idict.items()}
-        else:
-            freqs_work[key] = {order_key(key, key_separator):val for key, val in idict.items()}
-
-    # Implement replacements
+    # Enforce replacement dictionaries
     if replacement_dict is not None:
-        freqs_work = {key:{replace_w_dict(key2, replacement_dict):val2 for key2, val2 in val.items()} for key, val in freqs_work.items()}
+        freqs_work = {key: {replace_w_dict(key2, replacement_dict): val2 for key2, val2 in val.items()} for key, val in
+                      freqs_work.items()}
+
+    #Re - ordered keys if needed
+    if str(key_separator).lower() != "none" and len(key_separator) > 0:
+        freqs_work = {key : {order_key(key2, key_separator): val2 for key2, val2 in idict.items()} for key, idict in freqs_work.items()}
 
     if defrag is not None:
         freqs_work = {key:{defrag_key(key2, defrag):val2 for key2, val2 in val.items()} for key, val in freqs_work.items()}
@@ -280,7 +283,7 @@ def unify_freq_dicts(freqs,
             if key not in ifreq.keys():
                 ifreq[key] = val_missing
 
-    if len(not_shared)>0 and is_freq:
+    if len(not_shared)>0 and is_freq and verbose:
         print("These interactions are not shared:\n%s" % (', '.join(not_shared)))
         print("Their cumulative ctc freq is %3.2f. " % _np.sum(
             [[ifreq[key] for ifreq in freqs_work.values()] for key in not_shared]))
@@ -364,6 +367,86 @@ def sum_dict_per_residue(idict, sep):
         out_dict[key2].append(freq)
     return {key:_np.sum(val) for key, val in out_dict.items()}
 
+def sort_dict_by_asc_values(idict, reverse=False):
+    r""" Sort a dictionary by values
+
+    Parameters
+    ----------
+    idict : dict
+        Input dictionary
+    reverse : bool, default is False
+        Reverse the sorting order,
+        i.e. sort by ascending order
+        of values
+
+    Returns
+    -------
+    odict : dict
+        Indict sorted with its keys
+         sorted by its values
+    """
+    return {key: val for key, val in sorted(idict.items(), key=lambda item: item[1], reverse=reverse)}
+
+def lexsort_ctc_labels(ctc_labels, reverse=False, columns=[0,1], sep="-") -> tuple:
+    r"""
+    Sort contact-labels in ascending order of resSeq using both columns
+
+    Wraps around :obj:`numpy.lexsort` with some string handling
+
+    It will also work with contact-labels consisting of only one residue,
+    e.g. in the cases where the "anchor" has been deleted or the frequencies
+    have been aggregated to per-residue frequencies
+
+    >>> labels = ["ALA30@3.50-GLU50",
+    >>>           "HIS28-GLU50",
+    >>>           "ALA30-GLU20"]
+    >>> sorted_labels, order = mdciao.utils.str_and_dict.lexsort_ctc_labels(labels)
+    >>> sorted_ctc_labels
+    >>> ['HIS28-GLU50',
+    >>>  'ALA30-GLU20',
+    >>>  'ALA30@3.50-GLU50']
+
+    Parameters
+    ----------
+    ctc_labels : list of np.ndarray
+        Strings describing the contact
+        residues. It can contain also
+        fragment information, which
+        will be ignored when sorting
+        but returned in :obj:`sorted_ctc_labels`
+    reverse : bool, default is False
+        If True, sort in descending
+        order, instead of ascending
+    columns : list
+        The order of the columns,
+        e.g. [0,1] means sort first
+        by first column (idx 0),
+        then by second column (idx 1).
+    sep : char, default is "-"
+        The character to use
+        when separating the
+        contact label into both residues
+
+    Returns
+    -------
+    order : 1D np.ndarray
+        The indices of :obj:`ctc_labels` that
+        sort it into :obj:`sorted_ctc_labels`
+    sorted_ctc_labels : list
+        The sorted contact labels
+    """
+    resSeqs = _np.vstack(
+        [[intblocks_in_str(pp)[0] for pp in splitlabel(lab,sep)] for lab in ctc_labels])
+
+    if resSeqs.shape[1]==1:
+        order = _np.argsort(resSeqs.squeeze())
+    else:
+        order = _np.lexsort([resSeqs[:, columns[1]], resSeqs[:, columns[0]]])
+    if reverse:
+        order=order[::-1]
+    sorted_ctc_labels = [ctc_labels[ii] for ii in order]
+    return sorted_ctc_labels, order
+
 def freq_file2dict(ifile, defrag=None):
     r"""
     Read a file containing the frequencies ("freq") and labels ("label")
@@ -405,13 +488,31 @@ def freq_file2dict(ifile, defrag=None):
 
 def freq_ascii2dict(ifile, comment=["#"]):
     r"""
-    Reads an ascii file that contains contact frequencies (1st) column and
-    contact labels . Columns are separated by tabs or spaces.
+    Reads an ASCII file that contains contact frequencies
+    (1st column) and contact labels (2nd and/or 3rd column).
+    Columns are separated by tabs or spaces.
 
     Contact labels have to come after the frequency in the
     form of "res1 res2, "res1-res2" or "res1 - res2",
 
-    Columns other than the frequencies and the residue labels are ignored
+    Columns other than the frequencies and the residue labels are ignored.
+
+    Examples
+    --------
+    File produced by mdciao:
+
+    >>> #freq              label              residue idxs  sum
+    >>> 0.59 R389@G.H5.21    - L394@G.H5.26    348 353    0.59
+    >>> 0.46 L394@G.H5.26    - K270@6.32x32    353 972    1.05
+    >>> 0.34 L388@G.H5.20    - L394@G.H5.26    347 353    1.39
+    >>> 0.32 L394@G.H5.26    - L230@5.69x69    353 957    1.71
+    >>> 0.04 R385@G.H5.17    - L394@G.H5.26    344 353    1.75
+
+    Minimal file with mixed labeling
+
+    >>> 1 ALA30-GLU50
+    >>> .5 ASP31 - GLU51
+    >>> .1 ASP31 GLU50
 
 
     TODO use pandas to allow more flex, not needed for the moment
@@ -420,20 +521,21 @@ def freq_ascii2dict(ifile, comment=["#"]):
     ----------
     ifile : str
         The filename to be read
-
     comment : list of chars
         Any line starting with any of these
         characters will be ignored
     Returns
     -------
     freqdict : dictionary
+        Keys are "res1-res2" (regardless of input)
+        and values are freqs
 
     """
     #TODO consider using pandas
     outdict = {}
     with open(ifile) as f:
         for iline in f.read().splitlines():
-            if iline.strip()[0] not in comment:
+            if iline.strip()[0] not in comment and len(iline)>0:
                 try:
                     iline = iline.replace("-"," ").split()
                     freq, names = float(iline[0]),"%s-%s"%(iline[1],iline[2])
@@ -558,7 +660,7 @@ def latex_mathmode(istr, enclose=True):
 
     Works "opposite" to :obj:`replace4latex` and for the moment
     it's my (very bad) solution for latexifying contact-labels' fragments
-    as super indices where the the fragments themselves contain
+    as super indices where the fragments themselves contain
     sub-indices (GLU30^$\beta_2AR}
 
 
@@ -1112,6 +1214,10 @@ class FilenameGenerator(object):
         return self.fullpath_overall_fig.replace("overall@", "matrix@")
 
     @property
-    def fullpath_flare_pdf(self):
-        return '.'.join([self.fullpath_overall_no_ext.replace("overall@", "flare@"), 'pdf'])
+    def fullpath_flare_vec(self):
+        if self.graphic_ext == "svg":
+            gx = self.graphic_ext
+        else:
+            gx = "pdf"
+        return '.'.join([self.fullpath_overall_no_ext.replace("overall@", "flare@"),gx])
 
